SolveCore

Trait SolveCore 

pub trait SolveCore<T: ComplexField>: ShapeCore {
    // Required methods
    fn solve_in_place_with_conj(&self, conj: Conj, rhs: MatMut<'_, T>);
    fn solve_transpose_in_place_with_conj(&self, conj: Conj, rhs: MatMut<'_, T>);
}
linear system solver implementation

Required Methods

fn solve_in_place_with_conj(&self, conj: Conj, rhs: MatMut<'_, T>)

solves the equation self × x = rhs, implicitly conjugating self if needed, and stores the result in rhs

fn solve_transpose_in_place_with_conj(&self, conj: Conj, rhs: MatMut<'_, T>)

solves the equation self.transpose() × x = rhs, implicitly conjugating self if needed, and stores the result in rhs

Implementations on Foreign Types

Source

impl<T: ComplexField, S: ?Sized + SolveCore<T>> SolveCore<T> for &S

Source

fn solve_in_place_with_conj(&self, conj: Conj, rhs: MatMut<'_, T>)

Source

fn solve_transpose_in_place_with_conj(&self, conj: Conj, rhs: MatMut<'_, T>)

Implementors

Source

impl<I: Index, T: ComplexField> SolveCore<T> for faer::sparse::linalg::solvers::Llt<I, T>

Source

impl<I: Index, T: ComplexField> SolveCore<T> for Lu<I, T>

Source

impl<I: Index, T: ComplexField> SolveCore<T> for faer::sparse::linalg::solvers::Qr<I, T>

Source

impl<T: ComplexField> SolveCore<T> for ColPivQr<T>

Source

impl<T: ComplexField> SolveCore<T> for FullPivLu<T>

Source

impl<T: ComplexField> SolveCore<T> for Lblt<T>

Source

impl<T: ComplexField> SolveCore<T> for Ldlt<T>

Source

impl<T: ComplexField> SolveCore<T> for faer::linalg::solvers::Llt<T>

Source

impl<T: ComplexField> SolveCore<T> for PartialPivLu<T>

Source

impl<T: ComplexField> SolveCore<T> for faer::linalg::solvers::Qr<T>

Source

impl<T: ComplexField> SolveCore<T> for SelfAdjointEigen<T>

Source

impl<T: ComplexField> SolveCore<T> for Svd<T>