pub trait SolveLstsqCore<T: ComplexField>: ShapeCore {
// Required method
fn solve_lstsq_in_place_with_conj(&self, conj: Conj, rhs: MatMut<'_, T>);
}Expand description
least squares linear system solver implementation
Required Methods
Sourcefn solve_lstsq_in_place_with_conj(&self, conj: Conj, rhs: MatMut<'_, T>)
fn solve_lstsq_in_place_with_conj(&self, conj: Conj, rhs: MatMut<'_, T>)
solves the equation self × x = rhs in the sense of least squares, implicitly conjugating
self if needed, and stores the result in the top rows of rhs